@@ -29,7 +29,11 @@ import requests
 import validata_core
 from flasgger import swag_from
 from flask import request
-from validata_core.helpers import FileContentValidataResource, URLValidataResource
+from validata_core.helpers import (
+    FileContentValidataResource,
+    URLValidataResource,
+    ValidataSourceError,
+)
 
 from . import app, config
 from .json_errors import abort_json, make_json_response
@@ -68,6 +72,8 @@ def index():
     )
 
 
+base_url = "https://git.opendatafrance.net/scdl/deliberations"
+
 specs_dict = {
     "get": {
         "summary": "Validate a tabular file from its URL",
@@ -78,7 +84,7 @@ specs_dict = {
                 "type": "string",
                 "format": "url",
                 "description": "URL of schema to use for validation",
-                "example": "https://git.opendatafrance.net/scdl/deliberations/raw/master/schema.json",
+                "example": f"{base_url}/raw/master/schema.json",
                 "required": True,
             },
             {
@@ -87,7 +93,7 @@ specs_dict = {
                 "type": "string",
                 "format": "url",
                 "description": "URL of tabular file to validate",
-                "example": "https://git.opendatafrance.net/scdl/deliberations/raw/v2.0/examples/Deliberations_ok.csv",
+                "example": f"{base_url}/raw/v2.0/examples/Deliberations_ok.csv",
                 "required": True,
             },
         ],
@@ -102,7 +108,7 @@ specs_dict = {
                 "type": "string",
                 "format": "url",
                 "description": "URL of schema to use for validation",
-                "example": "https://git.opendatafrance.net/scdl/deliberations/raw/master/schema.json",
+                "example": f"{base_url}/raw/master/schema.json",
                 "required": True,
             },
             {
@@ -145,7 +151,12 @@ specs_dict = {
                                     {
                                         "code": "compare-columns-value",
                                         "column-number": 11,
-                                        "message": "La valeur de la colonne PREF_DATE [2017-02-03] devrait être supérieure ou égale à la valeur de la colonne DELIB_DATE [2017-10-15]",
+                                        "message": (
+                                            "La valeur de la colonne PREF_DATE"
+                                            " [2017-02-03] devrait être supérieure "
+                                            "ou égale à la valeur de la colonne"
+                                            " DELIB_DATE [2017-10-15]"
+                                        ),
                                         "message-data": {
                                             "column1": "PREF_DATE",
                                             "column2": "DELIB_DATE",
@@ -248,7 +259,17 @@ def validate():
             abort_json(400, args, 'Missing or empty "file" parameter')
         validata_resource = FileContentValidataResource(f.filename, bytes_data(f))
 
-    header, rows = validata_resource.extract_tabular_data()
+    try:
+        header, rows = validata_resource.extract_tabular_data()
+    except ValidataSourceError as err:
+        body = {
+            "error": {
+                "name": err.name,
+                "message": err.message,
+            }
+        }
+        return make_json_response(body, args)
+
     validation_report = validata_core.validate([header] + rows, schema_dict)
 
     body = {
